@@ -31,6 +31,7 @@
 
 #include "bluetooth-filter-widget.h"
 #include "bluetooth-client.h"
+#include "bluetooth-utils.h"
 #include "gnome-bluetooth-enum-types.h"
 
 #define BLUETOOTH_FILTER_WIDGET_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), \
@@ -55,7 +56,7 @@ struct _BluetoothFilterWidgetPrivate {
 	guint show_device_category : 1;
 };
 
-G_DEFINE_TYPE(BluetoothFilterWidget, bluetooth_filter_widget, GTK_TYPE_VBOX)
+G_DEFINE_TYPE(BluetoothFilterWidget, bluetooth_filter_widget, GTK_TYPE_BOX)
 
 enum {
 	DEVICE_TYPE_FILTER_COL_NAME = 0,
@@ -167,9 +168,13 @@ filter_type_changed_cb (GtkComboBox *widget, gpointer data)
 void
 bluetooth_filter_widget_set_title (BluetoothFilterWidget *self, gchar *title)
 {
+	gchar *markup;
 	BluetoothFilterWidgetPrivate *priv = BLUETOOTH_FILTER_WIDGET_GET_PRIVATE(self);
 
-	gtk_label_set_text (GTK_LABEL (priv->title), title);
+	markup = g_strdup_printf ("<b>%s</b>", title);
+	gtk_label_set_text (GTK_LABEL (priv->title), markup);
+	g_free (markup);
+
 	gtk_label_set_use_markup (GTK_LABEL (priv->title), TRUE);
 }
 
@@ -220,11 +225,13 @@ bluetooth_filter_widget_init(BluetoothFilterWidget *self)
 
 	gtk_widget_push_composite_child ();
 
+	g_object_set (G_OBJECT (self), "orientation", GTK_ORIENTATION_VERTICAL, NULL);
+
 	gtk_box_set_homogeneous (GTK_BOX (self), FALSE);
 	gtk_box_set_spacing (GTK_BOX (self), 6);
 
 	priv->title = gtk_label_new ("");
-	bluetooth_filter_widget_set_title (self, _("<b>Show Only Bluetooth Devices With...</b>"));
+	bluetooth_filter_widget_set_title (self, _("Show Only Bluetooth Devices With..."));
 	gtk_widget_show (priv->title);
 	gtk_box_pack_start (GTK_BOX (self), priv->title, TRUE, TRUE, 0);
 	gtk_misc_set_alignment (GTK_MISC (priv->title), 0, 0.5);
